@@ -44,12 +44,6 @@ if gs.GUIString == "GTK":
   import gobject
   import cairo
 
-#loadImage = None
-#def setLoadimage(function):
-#  loadImage = function
-#  print function
-#  return
-
 def getModule(m,d,i):
   return(MapTiles(m,d,i))
 
@@ -138,7 +132,7 @@ class MapTiles(ranaModule):
 
     # get layer info
     layerInfo = self.mapLayers.get(layer, None)
-    if layerInfo == None: # is the layer info valid ?
+    if layerInfo is None: # is the layer info valid ?
       print("mapTiles: invalid layer")
       return
     layerPrefix = layerInfo.get('folderPrefix','OpenStreetMap II')
@@ -149,13 +143,11 @@ class MapTiles(ranaModule):
       # tile was available from storage
       return tileData
 
-    print "download"
+#    print "download"
     url = self.getTileUrl(x,y,z,layer)
-    print url
-#    request = urllib2.urlopen(url)
-#    tileData = request.read()
+#    print url
     response = self._getConnPool(layer, url).get_url(url)
-    print "RESPONSE"
+#    print "RESPONSE"
     tileData = response.data
 
     if tileData:
@@ -164,8 +156,8 @@ class MapTiles(ranaModule):
         tileFolder = self.modrana.paths.getMapFolderPath()
         filePath = os.path.join(tileFolder, self.getImagePath(x, y, z, layerPrefix, layerType))
         self._storeTiles.automaticStoreTile(tileData, layerPrefix, z, x, y, layerType, filePath)
-        print "STORED"
-        return(tileData)
+#        print "STORED"
+        return tileData
       else:
         print("mapTiles: tile data returned by remote tileserver was not an image")
         print("NOTE: this probably means that the tileserver returned an"
@@ -214,14 +206,14 @@ class MapTiles(ranaModule):
     """
 
     layerInfo = self.mapLayers.get(layer, None)
-    if(layerInfo == None): # is the layer info valid ?
+    if layerInfo is None: # is the layer info valid ?
       print("mapTiles: invalid layer")
       return
     layerPrefix = layerInfo.get('folderPrefix','OpenStreetMap II')
     layerType = layerInfo.get('type','png')
     # Are we allowed to download it ? (network=='full')
     # -> no need to submit a download request if network access is disabled
-    if(self.get('network','full')=='full'):
+    if self.get('network','full') == 'full':
       filename = os.path.join(self._getTileFolderPath(), (self.getImagePath(x,y,z,layerPrefix, layerType)))
       # add tile download request
       with self.threadlListCondition:
@@ -291,7 +283,7 @@ class MapTiles(ranaModule):
           """
           self.threadlListCondition.wait()
           if self.shutdownAllThreads:
-            print "\nmapTiles: automatic tile download management thread shutting down"
+            print("\nmapTiles: automatic tile download management thread shutting down")
             break
           with self.downloadRequestPoolLock:
             activeThreads = len(self.threads)
@@ -337,7 +329,7 @@ class MapTiles(ranaModule):
                   self.removeImageFromMemmory(name)
               self.downloadRequestPool = cleanPool
         except Exception, e:
-          print "exception in tile download manager thread:\n%s" % e
+          print("exception in tile download manager thread:\n%s" % e)
 #          traceback.print_exc()
 
 #  def startTileLoadingThread(self):
@@ -420,8 +412,8 @@ class MapTiles(ranaModule):
 #              del self.threads[index]
 
       if self.get('reportTileCachStatus', False): # TODO: set to False by default
-        print "** tile cache status report **"
-        print "threads: %d, images: %d, special tiles: %d, downloadRequestPool:%d" % (len(self.threads), len(self.images[0]),len(self.images[1]),len(self.downloadRequestPool))
+        print("** tile cache status report **")
+        print("threads: %d, images: %d, special tiles: %d, downloadRequestPool:%d" % (len(self.threads), len(self.images[0]),len(self.images[1]),len(self.downloadRequestPool)))
 
 
     """seems that some added error handling in the download thread class can replace this,
@@ -483,7 +475,7 @@ class MapTiles(ranaModule):
         (sx,sy,sw,sh) = self.get('viewport') # get screen parameters
 
         # adjust left corner coordinates if centering shift is on
-        (shiftX,shiftY) = self.modrana.centerShift
+        (shiftX,shiftY) = self.modrana.gui.centerShift
         sx = -shiftX
         sy = -shiftY
         # get the current scale and related info
@@ -513,7 +505,7 @@ class MapTiles(ranaModule):
 
           # get the rotation angle
           angle = self.get('bearing', 0.0)
-          if angle == None:
+          if angle is None:
             angle = 0.0
 
           radAngle = radians(angle)
@@ -525,7 +517,7 @@ class MapTiles(ranaModule):
           # we use polygon overlap testing to only load@draw visible tiles
 
           # screen center point
-          (shiftX,shiftY) = self.modrana.centerShift
+          (shiftX,shiftY) = self.modrana.gui.centerShift
           (centerX,centerY) = ((sw/2.0),(sh/2.0))
           scP = rectangles.Point(centerX,centerY)
 
@@ -552,7 +544,7 @@ class MapTiles(ranaModule):
           v4 = rectangles.Vector(*p4.as_tuple())
 
           # enlarge the area of possibly visible tiles due to rotation
-          add = self.modrana.expandViewportTiles
+          add = self.modrana.gui.expandViewportTiles
           (px1,px2,py1,py2) = (px1-add,px2+add,py1-add,py2+add)
           cx = int(px1)
           cy = int(py1)
@@ -713,7 +705,7 @@ class MapTiles(ranaModule):
 #      pass
 
     except Exception, e:
-      print "mapTiles: exception while drawing the map layer: %s" % e
+      print("mapTiles: exception while drawing the map layer: %s" % e)
       traceback.print_exc()
 
   def drawImage(self, cr, imageSurface, x, y, scale):
@@ -790,19 +782,19 @@ class MapTiles(ranaModule):
     with self.threadlListCondition:
       if name in self.threads.keys():
         sprint("tile is being downloaded")
-        if(not self.threads[name].finished):
+        if not self.threads[name].finished:
           with self.imagesLock: # substitute the "loading" tile with a "downloading" tile
             downloadingTile = self.downloadingTile
             downloadingTile[1]['addedTimestamp'] = time.time()
             downloadingTile[1]['type'] = "downloading"
 
             self.images[0][name] = downloadingTile
-          return('OK')
+          return'OK'
     
     # second, is it in the disk cache?  (including ones recently-downloaded)
     layerInfo = self.mapLayers.get(layer, None)
-    if(layerInfo == None): # is the layer info valid
-      return('NOK')
+    if layerInfo is None: # is the layer info valid
+      return'NOK'
 
     layerPrefix = layerInfo.get('folderPrefix','OSM')
     layerType = layerInfo.get('type','png')
@@ -818,7 +810,7 @@ class MapTiles(ranaModule):
         storageType = self.get('tileStorageType', 'files')
         sprint("tile loaded from local storage (%s) in %1.2f ms" % (storageType,(1000 * (time.clock() - start1))))
         sprint("tile cached in memory in %1.2f ms" % (1000 * (time.clock() - start2)))
-      return('OK')
+      return 'OK'
 
     # Image not found anywhere locally - resort to downloading it
     filename = os.path.join(self._getTileFolderPath(), (self.getImagePath(x,y,z,layerPrefix, layerType)))
@@ -869,9 +861,9 @@ class MapTiles(ranaModule):
     """return a pixbuf for a given filePath"""
     try:
       pixbuf = gtk.gdk.pixbuf_new_from_file(filePath)
-      return(pixbuf)
+      return pixbuf
     except Exception, e:
-      print "the tile image is corrupted nad/or there are no tiles for this zoomlevel, exception:\n%s" % e
+      print("the tile image is corrupted nad/or there are no tiles for this zoomlevel, exception:\n%s" % e)
       return False
 
   def storeInMemmory(self, surface, name, type="normal", expireTimestamp=None, dictIndex=0):
@@ -879,9 +871,7 @@ class MapTiles(ranaModule):
        dictIndex = 0 -> normal map tiles + tile specific error tiles
        dictIndex = 1 -> special tiles that exist in only once in memory and are drawn directly
        (like "Downloading...",Waiting for download slot..:", etc.) """
-    metadata = {}
-    metadata['addedTimestamp'] = time.time()
-    metadata['type'] = type
+    metadata = {'addedTimestamp': time.time(), 'type': type}
     if expireTimestamp:
       metadata['expireTimestamp'] = expireTimestamp
     with self.imagesLock: #make sure no one fiddles with the cache while we are working with it
@@ -1092,17 +1082,17 @@ class MapTiles(ranaModule):
 
     def printErrorMessage(self, e):
         url = self.callback.getTileUrl(self.x,self.y,self.z,self.layer)
-        print "mapTiles: download thread reports error"
-        print "** we were doing this, when an exception occurred:"
-        print "** downloading tile: x:%d,y:%d,z:%d, layer:%s, filename:%s, url: %s" % ( \
+        print("mapTiles: download thread reports error")
+        print("** we were doing this, when an exception occurred:")
+        print("** downloading tile: x:%d,y:%d,z:%d, layer:%s, filename:%s, url: %s" % ( \
                                                                             self.x,
                                                                             self.y,
                                                                             self.z,
                                                                             self.layer,
                                                                             self.filename,
-                                                                            url)
-        print "** this exception occurred: %s\n" % e
-        print "** traceback:\n"
+                                                                            url))
+        print("** this exception occurred: %s\n" % e)
+        print("** traceback:\n")
         traceback.print_exc()
 
     def downloadTile(self,name,x,y,z,layer,filename):
